@@ -9,15 +9,15 @@ use POSIX qw(strftime);
 
 =head1 NAME
 
-SMS::API::QuickTelecom - QuickTelecom SMS services
+SMS::API::QuickTelecom - QuickTelecom SMS service on qtelecom.ru
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my @fields = qw(
     user pass host path ssl test
@@ -70,27 +70,23 @@ sub _get_post_request {
 
 =head1 SYNOPSIS
 
-Usage
-
     use SMS::API::QuickTelecom;
 
     my $qtsms = SMS::API::QuickTelecom->new(
         user => 'account-login',
         pass => 'account-password',
-        [host => 'hostname-to-query',]
-        [path => 'path-on-hostname-to-query',]
-        [ssl  => '1',]
-        [gzip  => 'none',]
-        [comment  => '',]
-        [HTTP_ACCEPT_LANGUAGE  => '',]
-        [CLIENTADR  => '',]
-        [sender  => '',]
     );
 
+    $qtsms->send_sms(message=>'Test-SMS', target=>'+799912345678');
+
+    print "Balance-XML:\n".$qtsms->balance();
+
 
 =head2 Overview
 
-A quick perl port of few classes from official QTSMS.class for SMS sending.
+A quick perl port of few classes from official PHP QTSMS.class for SMS sending.
+
+Default settings are set to use HTTPS for communication.
 
 =head1 METHODS
 
@@ -102,7 +98,7 @@ Instantiate and initialise object with the following:
 
 =over 4
 
-=item * user, pass
+=item * user
 
 Account username you receive during your registration. Mandatory.
 
@@ -116,25 +112,25 @@ Optional.
 
 Host name to perform POST/GET requests to. When using SSL (by default) it's default to L<go.qtelecom.ru>.
 
-If you are willing to use insecure communication via plain HTTP then host must be set to L<service.qtelecom.ru> and ssl=0.
+If you are willing to use insecure communication via plain HTTP then host must be set to L<service.qtelecom.ru> and C<ssl>=0.
 
 =item * path
 
 Optional.
 
-Path on server to perform requests. Default is L</public/http>.
+Path on server to perform requests. Default is C</public/http>.
 
 =item * ssl
 
 Optional.
 
-Flag to use SSL, default is L<1> (on). Optional.
+Flag to use SSL, default is C<1> (on). Optional.
 
 =item * gzip
 
 Optional.
 
-Flag to enable|disable gzip-encoding of data, possible values L<none> or L<on>, default is L<none> (do not use).
+Flag to enable|disable gzip-encoding of data, possible values are: C<none> or C<on>, default is C<none>.
 
 Optional
 
@@ -154,13 +150,15 @@ Langage to use for the returned data content.
 
 Optional.
 
-IP-address of the sender. Set to L<127.0.0.1> if not specified explicitly.
+IP-address of the sender.  If not specified will be set to C<127.0.0.1> internally.
 
 =item * sender
 
 Optional.
 
-Name of the sender, one of registered in system on https://go.qtelecom.ru.
+Name of the sender, registered in system on L<https://go.qtelecom.ru>.
+
+If not specified default setting from system will be used.
 
 =back
 
@@ -192,7 +190,7 @@ sub new {
 
 =head2 balance
 
-Returns an XML desribing account balance in the national currency.
+Returns an XML desribing account balance and overdraft in the national currency.
 
 Takes no parameters.
 
@@ -212,29 +210,29 @@ Sends a text SMS to one or more recipients.
 
 Mandatory.
 
-Message text to send. Enconding must be ASCII or UTF-8.
+Message text to send. Enconding must be ASCII or UTF-8. Internally module is using UTF-8 encoding.
 
 =item * target
 
 Mandatory.
 
-list of the recipients to send, comma delimited if there are more then one recipient:
+List of recipients to send message, comma delimited if there are more than one recipient:
 
-"+70010001212, 80009990000"
+  "+70010001212, 80009990000"
 
-Mutualy exclusive with L<phl_codename>
+Mutualy exclusive with C<phl_codename>
 
 =item * phl_codename
 
-Mutualy exclusive with L<target>, one or other is mandatory.
+Mutualy exclusive with C<target>, one or other is mandatory.
 
-Codename of a recipient via contatc-list created on https://go.qtelecom.ru.
+Codename of a recipient via contact-list created on L<https://go.qtelecom.ru>.
 
 =item * sender
 
 Optional.
 
-Sender's nickname, one of the registered on https://go.qtelecom.ru.
+Sender's nickname, one of the registered on L<https://go.qtelecom.ru>.
 
 =item * period
 
@@ -242,7 +240,7 @@ Optional.
 
 Time-to-Live for a message, units are second. Message will be discarded if system fails to deliver message over this period of time.
 
-Caution: this service may not work for some routes, like a CDMA phones.
+  Caution: this service may not work for some routes, like a CDMA phones.
 
 =item * time_period
 
@@ -250,16 +248,15 @@ Optional.
 
 Timeperiod during which message shall be delivered to the recipients (like 10:00-21:00).
 Use of this option allows to skip delivery of messages during night hours.
-For this service to work correctly one may specify L<time_local> timezone.
+For this service to work correctly you may specify L<time_local> timezone.
 
 =item * time_local
 
 Optional.
 
-Selection of time zone for L<time_period> option:
-
-1 - means L<time_period> is local time for the recipient,
-0 - means L<time_period> was spcified according to the sender settings.
+Selection of time zone for C<time_period> option:
+  1 - means C<time_period> is local time for the recipient,
+  0 - means C<time_period> was spcified according to the sender settings.
 
 =item * autotrimtext
 
@@ -295,9 +292,6 @@ Please report any bugs or feature requests to C<bug-sms-api-quicktelecom at rt.c
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SMS-API-QuickTelecom>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
